@@ -98,6 +98,7 @@ class PostExtractor:
             'text': None,
             'post_text': None,
             'shared_text': None,
+            'original_text': None,
             'time': None,
             'timestamp': None,
             'image': None,
@@ -296,10 +297,22 @@ class PostExtractor:
             post_text = paragraph_separator.join(post_text)
             shared_text = paragraph_separator.join(shared_text)
 
+            original_text = None
+            hidden_div = element.find('div[style="display:none"]', first=True)
+            if hidden_div:
+                original_text = []
+                for node in hidden_div.find("p,span[role=presentation]"):
+                    node = utils.make_html_element(
+                        html=node.html.replace('>… <', '><', 1).replace('>More<', '', 1)
+                    )
+                    original_text.append(node.text)
+                original_text = paragraph_separator.join(original_text)
+
             return {
                 'text': text,
                 'post_text': post_text,
                 'shared_text': shared_text,
+                'original_text': original_text,
             }
         elif element.find(".story_body_container>div", first=True):
             text = element.find(".story_body_container>div", first=True).text
@@ -628,7 +641,7 @@ class PostExtractor:
                 spriteMapCssClass = item["spriteMapCssClass"]
 
         reactors_opt = self.options.get("reactors")
-        limit = 3000
+        limit = 1e9
         if type(reactors_opt) in [int, float] and reactors_opt < limit:
             limit = reactors_opt
         logger.debug(f"Fetching {limit} reactors")
@@ -706,7 +719,7 @@ class PostExtractor:
             else:
                 share_url = None
 
-    def extract_reactions(self, post_id=None) -> PartialPost:
+    def extract_reactions(self, post_id=None, force_parse_HTML=False) -> PartialPost:
         """Fetch share and reactions information with a existing post obtained by `get_posts`.
         Return a merged post that has some new fields including `reactions`, `w3_fb_url`,
         `fetched_time`, and reactions fields `LIKE`, `ANGER`, `SORRY`, `WOW`, `LOVE`, `HAHA` if
@@ -743,8 +756,9 @@ class PostExtractor:
             reaction_url = f'https://m.facebook.com/ufi/reaction/profile/browser/?ft_ent_identifier={post_id}'
             logger.debug(f"Fetching {reaction_url}")
             response = self.request(reaction_url)
-
-            if not reactions:
+            if not reactions or force_parse_HTML:
+                reactions = {}
+                reaction_count = 0
                 for sigil in response.html.find("span[data-sigil='reaction_profile_sigil']"):
                     k = str(demjson.decode(sigil.attrs.get("data-store"))["reactionType"])
                     v = sigil.find(
@@ -756,6 +770,8 @@ class PostExtractor:
                     elif k in reaction_lookup:
                         name = reaction_lookup[k]["display_name"].lower()
                         reactions[name] = v
+                if not reaction_count:
+                    reaction_count = sum(reactions.values())
             reactors = self.extract_reactors(response, reaction_lookup)
 
         if reactions:
@@ -1002,7 +1018,7 @@ class PostExtractor:
                 'a[href^="/ufi/reaction/profile/browser/?ft_ent_identifier="] i', first=True
             )
             if reactors:
-                reactions = self.extract_reactions(comment_id)
+                reactions = self.extract_reactions(comment_id, force_parse_HTML=True)
                 if comment_reactors_opt != "generator":
                     reactions["reactors"] = utils.safe_consume(reactions.get("reactors", []))
 
@@ -1098,14 +1114,14 @@ class PostExtractor:
             more = elem.find(more_selector, first=True)
 
         # Comment limiting and progress
-        limit = 5000  # Default
+        limit = 1e9  # Default
         if more and more.attrs.get("data-ajaxify-href"):
             parsed = parse_qs(urlparse(more.attrs.get("data-ajaxify-href")).query)
             count = int(parsed.get("count")[0])
             if count < limit:
                 limit = count
         comments_opt = self.options.get('comments')
-        if type(comments_opt) in [int, float] and comments_opt < limit:
+        if type(comments_opt) in [int, float]:
             limit = comments_opt
         logger.debug(f"Fetching up to {limit} comments")
 
@@ -1151,6 +1167,7 @@ class PostExtractor:
                 logger.warning("No comments found on page")
                 break
             more_comments = elem.find(comments_selector)
+            comments.extend(more_comments)
             if not more_comments:
                 logger.warning("No comments found on page")
                 break
