@@ -6,7 +6,9 @@ import re
 from functools import partial
 from typing import Iterator, Union
 import json
-from urllib.parse import parse_qs, urlparse
+import demjson3 as demjson
+from urllib.parse import parse_qs, urlparse, unquote
+from datetime import datetime
 
 from requests import RequestException
 from requests_html import HTMLSession
@@ -514,6 +516,55 @@ class FacebookScraper:
 
         return result
 
+    def get_page_reviews(self, page, **kwargs) -> Iterator[Post]:
+        more_url = f"/{page}/reviews"
+        while more_url:
+            logger.debug(f"Fetching {more_url}")
+            response = self.get(more_url)
+            if response.text.startswith("for (;;);"):
+                prefix_length = len('for (;;);')
+                data = json.loads(response.text[prefix_length:])  # Strip 'for (;;);'
+                for action in data['payload']['actions']:
+                    if action['cmd'] == 'replace' and action['html']:
+                        element = utils.make_html_element(
+                            action['html'],
+                            url=FB_MOBILE_BASE_URL,
+                        )
+                        elems = element.find('#page_suggestions_on_liking ~ div')
+                    elif action['cmd'] == 'script':
+                        more_url = re.search(
+                            r'see_more_cards_id","href":"([^"]+)"', action["code"]
+                        )
+                        if more_url:
+                            more_url = more_url.group(1)
+                            more_url = utils.decode_css_url(more_url)
+                            more_url = more_url.replace("\\", "")
+            else:
+                elems = response.html.find('#page_suggestions_on_liking ~ div')
+                more_url = re.search(r'see_more_cards_id",href:"([^"]+)"', response.text)
+                if more_url:
+                    more_url = more_url.group(1)
+
+            for elem in elems:
+                links = elem.find("a")
+                if not links:
+                    continue
+                text_elem = elem.find("div[data-nt='FB:FEED_TEXT']", first=True)
+                date_element = elem.find("abbr[data-store*='time']", first=True)
+                time = json.loads(date_element.attrs["data-store"])["time"]
+                yield {
+                    "user_url": utils.urljoin(FB_BASE_URL, links[0].attrs["href"]),
+                    "username": links[0].text,
+                    "profile_picture": elem.find("img", first=True).attrs["src"],
+                    "text": text_elem.find("span p", first=True).text,
+                    "time": datetime.fromtimestamp(time),
+                    "timestamp": time,
+                    "recommends": "</span> recommends <span>" in elem.html,
+                    "post_url": utils.urljoin(
+                        FB_BASE_URL, text_elem.find("a[href*='story']", first=True).attrs["href"]
+                    ),
+                }
+
     def get_page_info(self, page, **kwargs) -> Profile:
         result = {}
         desc = None
@@ -541,16 +592,27 @@ class FacebookScraper:
             logger.debug(f"Requesting page from: {url}")
             resp = self.get(url)
             desc = resp.html.find("meta[name='description']", first=True)
+            ld_json = None
             try:
-                elem = resp.html.find("script[type='application/ld+json']", first=True)
-                meta = json.loads(elem.text)
+                ld_json = resp.html.find("script[type='application/ld+json']", first=True).text
+            except:
+                logger.error("No ld+json element")
+                url = f'/{page}/community'
+                logger.debug(f"Requesting page from: {url}")
+                try:
+                    community_resp = self.get(url)
+                    ld_json = community_resp.html.find(
+                        "script[type='application/ld+json']", first=True
+                    ).text
+                except:
+                    logger.error("No ld+json element")
+            if ld_json:
+                meta = demjson.decode(ld_json)
                 result.update(meta["author"])
                 result["type"] = result.pop("@type")
                 for interaction in meta.get("interactionStatistic", []):
                     if interaction["interactionType"] == "http://schema.org/FollowAction":
                         result["followers"] = interaction["userInteractionCount"]
-            except:
-                logger.error("No ld+json element")
             try:
                 result["about"] = resp.html.find(
                     '#pages_msite_body_contents>div>div:nth-child(2)', first=True
@@ -578,6 +640,7 @@ class FacebookScraper:
                         result["phone"] = link.replace("tel:", "")
                     if link.startswith("mailto:"):
                         result["email"] = link.replace("mailto:", "")
+            result["rating"] = resp.html.find("div[data-nt='FB:TEXT4']")[1].text
         except Exception as e:
             logger.error(e)
         if desc:
@@ -589,6 +652,7 @@ class FacebookScraper:
             if len(bits) == 3:
                 result["people_talking_about_this"] = utils.parse_int(bits[1])
                 result["checkins"] = utils.parse_int(bits[2])
+        result["reviews"] = self.get_page_reviews(page, **kwargs)
 
         return result
 
@@ -618,7 +682,26 @@ class FacebookScraper:
         logger.debug(f"Requesting page from: {url}")
         try:
             resp = self.get(url).html
-            admins = resp.find("div:first-child>div.touchable a:not(.touchable)")
+            url = resp.find("a[href*='listType=list_admin_moderator']", first=True)
+            if url:
+                url = url.attrs.get("href")
+                logger.debug(f"Requesting page from: {url}")
+                try:
+                    respAdmins = self.get(url).html
+                except:
+                    raise exceptions.UnexpectedResponse("Unable to get admin list")
+            else:
+                respAdmins = resp
+            # Test if we are a member that can add new members
+            if re.match(
+                "/groups/members/search",
+                respAdmins.find(
+                    "div:nth-child(1)>div:nth-child(1) a:not(.touchable)", first=True
+                ).attrs.get('href'),
+            ):
+                admins = respAdmins.find("div:nth-of-type(2)>div.touchable a:not(.touchable)")
+            else:
+                admins = respAdmins.find("div:first-child>div.touchable a:not(.touchable)")
             result["admins"] = [
                 {
                     "name": e.text,
@@ -626,7 +709,8 @@ class FacebookScraper:
                 }
                 for e in admins
             ]
-            url = resp.find("a[href^='/browse/group/members']", first=True)
+
+            url = resp.find("a[href*='listType=list_nonfriend_nonadmin']", first=True)
             if url:
                 url = url.attrs["href"]
                 members = []
@@ -729,6 +813,8 @@ class FacebookScraper:
                 warnings.warn(
                     f"Facebook served mbasic/noscript content unexpectedly on {response.url}"
                 )
+            if response.html.find("h1,h2", containing="Unsupported Browser"):
+                warnings.warn(f"Facebook says 'Unsupported Browser'")
             title = response.html.find("title", first=True)
             not_found_titles = ["page not found", "content not found"]
             temp_ban_titles = [
