@@ -148,7 +148,9 @@ class PageParser:
 
     def get_page(self) -> Page:
         # Select only elements that have the data-ft attribute
-        return self._get_page('[data-ft*="top_level_post_id"]', 'article')
+        return self._get_page(
+            '[data-ft*="top_level_post_id"]:not([data-sigil="m-see-translate-link"])', 'article'
+        )
 
     def get_raw_page(self) -> RawPage:
         return self.html
